# WELCOME

    betterprints is a python package meant to help with alternatives to the usual print() options, adding new tools to your coding arsenal.

## MAIN FUNCTIONS

- debugprint(): can be turned on and off (for production environments) using the function toggleDebugMode on you config class
- betterprint(): overall a more versatile way to print, adds styling options and type recognitions
- styledprint(): your good old print() friend with beautiful color options!
- classprint(): prints all user made classes attributes and instace detailing

## DISCLAIMER

This package is an experimental package made from a student, it is not yet finished and need some serious upgrading, any feedback is welcome, and you can further colaborate at Github<https://github.com/gui23dib/python-better-prints>
